@@ -4,10 +4,9 @@ use strict;
 
 use Carp();
 
-use Rose::HTML::Form::Field::Option::Container;
-our @ISA = qw(Rose::HTML::Form::Field::Option::Container);
+use base 'Rose::HTML::Form::Field::Option::Container';
 
-our $VERSION = '0.554';
+our $VERSION = '0.606';
 
 __PACKAGE__->add_required_html_attrs(
 {
@@ -386,4 +385,4 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 LICENSE
 
-Copyright (c) 2009 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2010 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
